<?php

namespace Drupal\fmm_extras\Plugin\Field\FieldFormatter;

use Drupal\Component\Utility\Xss;
use Drupal\Core\Field\Plugin\Field\FieldFormatter\EntityReferenceLabelFormatter;
use Drupal\Core\Field\Attribute\FieldFormatter;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\Core\Url;

/*
 * Plugin implementation of the 'fillpdf_file_url' formatter.
 *
 * Based on the 'file_url_plain' formatter.
 *
 * @TODO allow more (all?) field types.
 */
#[FieldFormatter(
  id: 'fmm_extras_reference_label_formatter',
  label: new TranslatableMarkup('Label plus edit link to a Form Mode Manager tab'),
  field_types: [
    'entity_reference',
  ],
)]
class FormModeEntityReferenceLabelFormatter extends EntityReferenceLabelFormatter {

  /**
   * {@inheritdoc}
   */
  public function view(FieldItemListInterface $items, $langcode = NULL) {
    $entity = $items->getEntity();
    // Do not show button to people without edit access.
    // @TODO add check for access to the specific form mode too.
    if (!$entity->access('update', \Drupal::currentUser())) {
      return parent::view($items, $langcode);
    }
    $elements = parent::view($items, $langcode);
    $entity_type_id = $entity->getEntityType()->id();
    // @TODO Un-hardcode the form mode ID!
    $form_mode_id = 'application_forms';
    // Do this better if https://www.drupal.org/project/form_mode_manager/issues/3530995 gets an answer.
    // should end up like /node/770209/edit/application_forms
    $edit_url = Url::fromRoute("entity.$entity_type_id.edit_form.$form_mode_id", [$entity_type_id => $entity->id()])->toString();
    // Annoyingly the suffix is entirely after the field wrappers so best we 
    // can do to have it look good is add another fake wrapper.
    $elements['#suffix'] = Xss::filterAdmin('<div class="field"><div class="field__label"></div><div class="field__item"><a class="button button--action button--primary" href="' . $edit_url . '">Add or change PDFs</a></div></div>');
    return $elements;
  }


}
